//
//  IAViewController.m
//  Speed Map
//
//  Created by Brendan G. Lim on 7/19/13.
//  Copyright (c) 2013 iOS in Action. All rights reserved.
//

#import "IAViewController.h"
#import <CoreLocation/CoreLocation.h>
#import <MapKit/MapKit.h>

@interface IAViewController ()

@end

#define kMetersPerSecondToMilesPerHour 2.2369362920544

@implementation IAViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.geocoder = [[CLGeocoder alloc] init];
    
    self.locationManager = [[CLLocationManager alloc] init];
    self.locationManager.desiredAccuracy = kCLLocationAccuracyBest;
    self.locationManager.distanceFilter = 1.0f;
    self.locationManager.delegate = self;
    
    [self.locationManager startUpdatingLocation];
    [self.mapView setUserTrackingMode:MKUserTrackingModeFollowWithHeading];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (void)locationManagerDidPauseLocationUpdates:(CLLocationManager *)manager
{
    self.speedLabel.text = @"";
    self.locationLabel.text = @"Location unavailable";
}

- (void)locationManagerDidResumeLocationUpdates:(CLLocationManager *)manager
{
}

- (void)locationManager:(CLLocationManager *)manager didUpdateLocations:(NSArray *)locations
{
    CLLocation *location = [locations lastObject];
    NSString *speedString = [NSString stringWithFormat:@"%d",
                             [@(location.speed * kMetersPerSecondToMilesPerHour) intValue]];

    MKCoordinateRegion region = MKCoordinateRegionMakeWithDistance(location.coordinate, 1000, 1000);
    [self.mapView setRegion:region animated:YES];

    self.speedLabel.text = speedString;
    
    if (![self.geocoder isGeocoding])
    {
        [self.geocoder reverseGeocodeLocation:location
                            completionHandler:^(NSArray *placemarks, NSError *error)
         {
             if (placemarks && [placemarks count] > 0 && error == nil) {
                 CLPlacemark *placemark = [placemarks lastObject];
                 NSString *locationString = [NSString stringWithFormat:@"%@, %@",
                                             placemark.subAdministrativeArea, placemark.administrativeArea];
                 
                 self.locationLabel.text = locationString;
             }
         }];
        
    }
}

- (IBAction)toggleMap:(id)sender
{
    [self.mapView setHidden:![self.mapView isHidden]];
}

@end
