//
//  IAExternalViewController.m
//  AirMusic
//
//  Created by Brendan G. Lim on 9/5/13.
//  Copyright (c) 2013 iOS in Action. All rights reserved.
//

#import "IAExternalViewController.h"

@interface IAExternalViewController ()

@end

@implementation IAExternalViewController

- (id)initWithWindowFrame:(CGRect)windowFrame withSongQueue:(MPMediaItemCollection *)songQueue
{
    self = [super initWithNibName:nil bundle:nil];
    if (self)
    {
        self.windowFrame = windowFrame;
        self.songQueue = songQueue;
    }
    
    return self;
}

- (void)loadView
{
    UIView *view = [[UIView alloc] initWithFrame:self.windowFrame];
    [view setBackgroundColor:[UIColor whiteColor]];
    
    float widthHeight = view.bounds.size.width / 4;
    CGRect imageFrame = CGRectMake((view.bounds.size.width - widthHeight)/2,
                                   (view.bounds.size.height - widthHeight)/3,
                                   widthHeight, widthHeight);
    
    self.albumImageView = [[UIImageView alloc] initWithFrame:imageFrame];
    [view addSubview:self.albumImageView];
    
    CGRect artistLabelFrame = CGRectMake(0,
                                         imageFrame.origin.y + imageFrame.size.height + (imageFrame.size.height / 5),
                                         view.bounds.size.width,
                                         45.0f);
    self.artistLabel = [[UILabel alloc] initWithFrame:artistLabelFrame];
    [self.artistLabel setFont:[UIFont boldSystemFontOfSize:40.0f]];
    [self.artistLabel setTextAlignment:NSTextAlignmentCenter];
    [view addSubview:self.artistLabel];
    
    CGRect songLabelFrame = CGRectMake(0,
                                       artistLabelFrame.origin.y + 55.0f,
                                       artistLabelFrame.size.width,
                                       artistLabelFrame.size.height);
    self.songLabel = [[UILabel alloc] initWithFrame:songLabelFrame];
    [self.songLabel setFont:[UIFont systemFontOfSize:30.0f]];
    [self.songLabel setTextAlignment:NSTextAlignmentCenter];
    [view addSubview:self.songLabel];
    
    [self setView:view];
}

- (void)populateViewsWithSongQueue
{
    MPMediaItem *mediaItem = self.songQueue.items[0];
    MPMediaItemArtwork *albumArtwork = [mediaItem valueForProperty:MPMediaItemPropertyArtwork];
    NSString *artistName = [mediaItem valueForProperty:MPMediaItemPropertyAlbumArtist];
    NSString *songName = [mediaItem valueForProperty:MPMediaItemPropertyTitle];
    
    if (albumArtwork)
        [self.albumImageView setImage:[albumArtwork imageWithSize:self.albumImageView.bounds.size]];
    
    if (artistName)
        self.artistLabel.text = artistName;
    
    if (songName)
        self.songLabel.text = songName;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    [self populateViewsWithSongQueue];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

@end
