//
//  IAExternalViewController.h
//  AirMusic
//
//  Created by Brendan G. Lim on 9/1/13.
//  Copyright (c) 2013 iOS in Action. All rights reserved.
//

#import <MediaPlayer/MediaPlayer.h>
#import "IAExternalViewController.h"
#import "IAViewController.h"

@interface IAViewController ()

@end

@implementation IAViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

    [self addAirPlayControls];

    MPMusicPlayerController *player = [MPMusicPlayerController iPodMusicPlayer];
    if ([player nowPlayingItem])
    {
        self.songQueue = [[MPMediaItemCollection alloc] initWithItems:@[player.nowPlayingItem]];
        [self populateViewsWithSongQueue];
    }
    
    [self checkForAndSetupExternalScreen];

    [[NSNotificationCenter defaultCenter] addObserver:self
											 selector:@selector(screenDidConnect:)
												 name:UIScreenDidConnectNotification
											   object:nil];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
											 selector:@selector(screenDidDisconnect:)
												 name:UIScreenDidDisconnectNotification
											   object:nil];

}

- (void)screenDidConnect:(NSNotification *) notification
{
    [self checkForAndSetupExternalScreen];
}

- (void)screenDidDisconnect:(NSNotification *) notification
{
    if (self.externalWindow)
    {
        [self.externalWindow setHidden:YES];
        self.externalWindow = nil;
    }
}

- (void)checkForAndSetupExternalScreen
{
    if ([[UIScreen screens] count] > 1)
    {
        UIScreen *screen = [UIScreen screens][1];
        self.externalWindow = [[UIWindow alloc] initWithFrame:screen.bounds];
        [self.externalWindow setScreen:screen];
        
        MPMediaItem *mediaItem = nil;
        if (self.songQueue && [self.songQueue.items count] > 0)
            mediaItem = self.songQueue.items[0];
        
        if (!self.externalView)
        {
            self.externalView = [[IAExternalViewController alloc] initWithWindowFrame:screen.bounds withSongQueue:self.songQueue];
            [self.externalWindow setRootViewController:self.externalView];
        }
        else
        {
            self.externalView.songQueue = self.songQueue;
            [self.externalView populateViewsWithSongQueue];
        }
        
        [self.externalWindow setHidden:NO];
    }
}

- (void)addAirPlayControls
{
    NSMutableArray *items = [self.controlToolbar.items mutableCopy];
    MPVolumeView *airPlayView = [[MPVolumeView alloc] initWithFrame:CGRectMake(0, 0, 150, 20)];
    [airPlayView setShowsVolumeSlider:YES];
    [airPlayView setShowsRouteButton:YES];
    [airPlayView sizeToFit];
    
    UIBarButtonItem *airPlayButtonItem = [[UIBarButtonItem alloc] initWithCustomView:airPlayView];
    self.controlToolbar.items = [items arrayByAddingObject:airPlayButtonItem];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (IBAction)chooseMusic:(id)sender
{
    MPMediaPickerController *picker = [[MPMediaPickerController alloc] initWithMediaTypes:MPMediaTypeMusic];
    [picker setDelegate:self];
    
    [self presentViewController:picker animated:YES completion:nil];
}

- (IBAction)playMusic:(id)sender
{
    MPMusicPlayerController *player = [MPMusicPlayerController iPodMusicPlayer];
    [player setQueueWithItemCollection:self.songQueue];
    [player play];

    if (self.externalView)
    {
        self.externalView.songQueue = self.songQueue;
        [self.externalView populateViewsWithSongQueue];
    }
}

- (IBAction)pauseMusic:(id)sender
{
    MPMusicPlayerController *player = [MPMusicPlayerController iPodMusicPlayer];
    [player pause];
}

- (void)populateViewsWithSongQueue
{
    MPMediaItem *mediaItem = self.songQueue.items[0];
    MPMediaItemArtwork *albumArtwork = [mediaItem valueForProperty:MPMediaItemPropertyArtwork];
    NSString *artistName = [mediaItem valueForProperty:MPMediaItemPropertyAlbumArtist];
    NSString *songName = [mediaItem valueForProperty:MPMediaItemPropertyTitle];
    
    if (albumArtwork)
        [self.albumImageView setImage:[albumArtwork imageWithSize:self.albumImageView.bounds.size]];
    
    if (artistName)
        self.artistLabel.text = artistName;
    
    if (songName)
        self.songLabel.text = songName;
}

- (void)mediaPicker:(MPMediaPickerController *)mediaPicker didPickMediaItems:(MPMediaItemCollection *)mediaItemCollection
{
    [mediaPicker dismissViewControllerAnimated:YES completion:nil];
    
    if ([mediaItemCollection.items count] > 0)
    {
        self.songQueue = mediaItemCollection;
        [self populateViewsWithSongQueue];
        [self playMusic:self];
    }
}

- (void)mediaPickerDidCancel:(MPMediaPickerController *)mediaPicker
{
    [mediaPicker dismissViewControllerAnimated:YES completion:nil];
}

- (void)viewDidDisappear:(BOOL)animated
{
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

@end
