//
//  IAAlbumsViewController.m
//  Albums
//
//  Created by Brendan G. Lim on 2/25/13.
//  Copyright (c) 2013 iOS in Action. All rights reserved.
//

#import "IAAlbumsViewController.h"
#import "IAAssetsLibrary.h"
#import "IAAlbumTableViewCell.h"
#import "IAAlbumPhotosViewController.h"

@interface IAAlbumsViewController ()

@end

@implementation IAAlbumsViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

    self.albums = [NSMutableArray array];
    [self loadAlbums];
}

- (void)loadAlbums
{
    IAAssetsLibrary *library = [IAAssetsLibrary defaultInstance];    
    [library enumerateGroupsWithTypes:ALAssetsGroupAll usingBlock:^(ALAssetsGroup *group, BOOL *stop)
    {
        if(group)
            [self.albums addObject:group];

        if (stop) {
            [self.tableView performSelectorOnMainThread:@selector(reloadData)
                                             withObject:nil
                                          waitUntilDone:YES];
            
        }
    }
                         failureBlock:^(NSError *error)
    {
        NSLog(@"Problem loading albums: %@", error);
    }];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.albums count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
	static NSString *CellIdentifier = @"albumCell";
	IAAlbumTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    [cell setFromAlbum:self.albums[indexPath.row]];
    
    return cell;
}

- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    return YES;
}

- (UITableViewCellEditingStyle)tableView:(UITableView *)tableView editingStyleForRowAtIndexPath:(NSIndexPath *)indexPath {
    return UITableViewCellEditingStyleDelete;
}

- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{ 
    if (editingStyle == UITableViewCellEditingStyleDelete)
    {
        [self.albums removeObjectAtIndex:indexPath.row];
        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    NSIndexPath *selectedIndex = [self.tableView indexPathForSelectedRow];
    [(IAAlbumPhotosViewController *)[segue destinationViewController] setAlbum:self.albums[selectedIndex.row]];
	[self.tableView deselectRowAtIndexPath:selectedIndex animated:YES];
}

@end
