//
//  IAAssetInfoViewController.m
//  Media Info
//
//  Created by Brendan G. Lim on 6/2/13.
//  Copyright (c) 2013 iOS in Action. All rights reserved.
//

#import "IAAssetInfoViewController.h"
#import "IAAssetsLibrary.h"

@interface IAAssetInfoViewController ()

@end

#define kExif @"{Exif}"
#define kTitle @"title"
#define kValue @"value"

@implementation IAAssetInfoViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    [self retrieveAsset];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (void)retrieveAsset
{
    [[IAAssetsLibrary defaultInstance] assetForURL:self.assetURL
                                       resultBlock:^(ALAsset *asset)
    {
        [self setupViewFromAsset:asset];
    }
                                      failureBlock:^(NSError *error)
    {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Oops!"
                                                        message:@"We couldn't load that asset"
                                                       delegate:nil
                                              cancelButtonTitle:@"Okay"
                                              otherButtonTitles:nil, nil];
        [alert show];
    }];
}

- (void)setupViewFromAsset:(ALAsset *)asset
{
    self.asset = asset;
    self.title = self.asset.defaultRepresentation.filename;
    UIImage *image = [UIImage imageWithCGImage:self.asset.defaultRepresentation.fullScreenImage];
    
    [self.imageView setImage:image];
    [self retrieveMetadata];
}

- (void)retrieveMetadata
{
    self.metadata = [NSMutableArray new];
    
    if ([[self.asset valueForProperty:ALAssetPropertyType] isEqualToString:ALAssetTypePhoto])
        [self retrievePhotoMetadata];
    else
        [self retrieveVideoMetadata];
}

- (void)retrievePhotoMetadata
{
    NSDictionary *meta = [[self.asset defaultRepresentation] metadata];
    NSDictionary *exif = meta[kExif];
    for (id key in exif)
    {
        id value = exif[key];
        if (value && ![value isKindOfClass:[NSArray class]] && ![value isKindOfClass:[NSDictionary class]])
            [self.metadata addObject:@{kTitle : key,
                             kValue : [NSString stringWithFormat:@"%@", value]}];
    }
    
    [self.tableView reloadData];
}

- (void) retrieveVideoMetadata
{
    [self.metadata addObject:@{kTitle: ALAssetPropertyDate,
                      kValue: [self.asset valueForProperty:ALAssetPropertyDate]}];
    [self.metadata addObject:@{kTitle: ALAssetPropertyDuration,
                      kValue: [self.asset valueForProperty:ALAssetPropertyDuration]}];
    [self.metadata addObject:@{kTitle: ALAssetPropertyLocation,
                      kValue: [self.asset valueForProperty:ALAssetPropertyLocation]}];
}

- (NSInteger) tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.metadata count];
}

- (UITableViewCell *) tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil)
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
    
    NSDictionary *data = self.metadata[indexPath.row];
    cell.textLabel.text = data[kTitle];
    cell.detailTextLabel.text = data[kValue];
    
    return cell;
}

@end
