//
//  IAViewController.m
//  Media Info
//
//  Created by Brendan G. Lim on 6/2/13.
//  Copyright (c) 2013 iOS in Action. All rights reserved.
//

#import <MobileCoreServices/MobileCoreServices.h>
#import "IAViewController.h"
#import "IAAssetInfoViewController.h"
#import "IAAssetsLibrary.h"

@interface IAViewController ()

@end

@implementation IAViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (IBAction)launchImagePicker:(id)sender
{
    UIImagePickerController *picker = [[UIImagePickerController alloc] init];
    picker.delegate = self;
    picker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;
    picker.mediaTypes = [UIImagePickerController availableMediaTypesForSourceType:picker.sourceType];
    [self presentViewController:picker animated:YES completion:nil];
}

- (IBAction)launchCamera:(id)sender
{
    if (![UIImagePickerController isSourceTypeAvailable:UIImagePickerControllerSourceTypeCamera])
    {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Sorry!"
                                                        message:@"No camera available"
                                                       delegate:nil
                                              cancelButtonTitle:@"Okay"
                                              otherButtonTitles:nil, nil];
        [alert show];
    }
    else
    {
        UIImagePickerController *picker = [[UIImagePickerController alloc] init];
        picker.sourceType = UIImagePickerControllerSourceTypeCamera;
        picker.mediaTypes = [UIImagePickerController availableMediaTypesForSourceType:picker.sourceType];
        picker.videoQuality = UIImagePickerControllerQualityTypeHigh;
        picker.videoMaximumDuration = 300;
        picker.delegate = self;

        [self presentViewController:picker animated:YES completion:nil];
    }
}

- (void)imagePickerController:(UIImagePickerController *)picker didFinishPickingMediaWithInfo:(NSDictionary *)info
{
    if (picker.sourceType == UIImagePickerControllerSourceTypeCamera)
    {
        [self saveMediaThenViewAsset:info];
    }
    else
    {
        [picker dismissViewControllerAnimated:YES completion:nil];
        NSURL *assetURL = info[UIImagePickerControllerReferenceURL];
        [self viewAssetFromURL:assetURL];
    }
}

- (void)viewAssetFromURL:(NSURL *)assetURL
{
    [self performSegueWithIdentifier:@"assetView" sender:assetURL];
}

- (void)saveMediaThenViewAsset:(NSDictionary *)info
{
    NSString *mediaType = info[UIImagePickerControllerMediaType];

    if ([mediaType isEqualToString:(NSString *)kUTTypeImage])
    {
        UIImage *image = info[UIImagePickerControllerOriginalImage];
        [[IAAssetsLibrary defaultInstance] writeImageToSavedPhotosAlbum:image.CGImage
                                                            orientation:(ALAssetOrientation)image.imageOrientation
                                                        completionBlock:^(NSURL *assetURL, NSError *error)
        {
            [self viewAssetFromURL:assetURL];
        }];
    }
    else if ([mediaType isEqualToString:(NSString *)kUTTypeVideo])
    {
        NSURL *mediaURL = info[UIImagePickerControllerMediaURL];
        [[IAAssetsLibrary defaultInstance] writeVideoAtPathToSavedPhotosAlbum:mediaURL
                                                              completionBlock:^(NSURL *assetURL, NSError *error)
        {
            [self viewAssetFromURL:assetURL];
        }];
    }
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue
                 sender:(id)sender
{
    [(IAAssetInfoViewController *)[segue destinationViewController] setAssetURL:sender];
}

@end
