//
//  IAAccountsViewController.m
//  TweetBook
//
//  Created by Brendan G. Lim on 11/16/12.
//  Copyright (c) 2012 Brendan Lim. All rights reserved.
//

#import "IAAccountsViewController.h"
#import "IAStreamViewController.h"

@interface IAAccountsViewController ()

@end

@implementation IAAccountsViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.accounts = [[NSMutableArray alloc] init];
    
    [self retrieveAccounts:ACAccountTypeIdentifierTwitter options:nil];
    
    NSDictionary *fbOptions = @{ ACFacebookAppIdKey: @"ADD YOUR KEY HERE",
                                 ACFacebookPermissionsKey: @[@"email",@"user_about_me"] };
    
    [self retrieveAccounts:ACAccountTypeIdentifierFacebook options:fbOptions];
}

-(void)retrieveAccounts:(NSString *)identifier options:(NSDictionary *)options
{
    ACAccountStore *accountStore = [[ACAccountStore alloc] init];
    ACAccountType *accountType = [accountStore accountTypeWithAccountTypeIdentifier:identifier];
    
    [accountStore requestAccessToAccountsWithType:accountType options:options completion:^(BOOL granted, NSError *error)
    {
         if(granted)
         {
             [self.accounts addObjectsFromArray:[accountStore accountsWithAccountType:accountType]];

             dispatch_async(dispatch_get_main_queue(), ^{
                 [self.tableView reloadData];
             });
         }
    }];
}
     
- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.accounts count];
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"accountCell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    if (!cell)
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier];
    
    ACAccount *account = self.accounts[indexPath.row];

    if ([account.accountType.identifier isEqualToString:ACAccountTypeIdentifierTwitter])
        cell.textLabel.text = account.accountDescription;
    else
        cell.textLabel.text = account.username;
    
    return cell;
}

- (void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    NSIndexPath *selectedIndex = self.tableView.indexPathForSelectedRow;
    ACAccount *account = [self.accounts objectAtIndex:selectedIndex.row];
    
    IAStreamViewController *view = [segue destinationViewController];
    view.title = [self.tableView cellForRowAtIndexPath:selectedIndex].textLabel.text;
    view.account = account;
}

@end
