//
//  BLStreamViewController.m
//  TweetBook
//
//  Created by Brendan G. Lim on 11/19/12.
//  Copyright (c) 2012 Brendan Lim. All rights reserved.
//

#import "IAStreamViewController.h"

@interface IAStreamViewController ()

@end

@implementation IAStreamViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    if ([self.account.accountType.identifier isEqualToString:ACAccountTypeIdentifierTwitter])
        [self retrieveTwitterStream];
    else
        [self retrieveFacebookStream];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (IBAction)postToStream:(id)sender
{
    if ([self.account.accountType.identifier isEqualToString:ACAccountTypeIdentifierTwitter])
        [self postToTwitter];
    else
        [self postToFacebook];
}

- (void)postToTwitter
{
    if([SLComposeViewController isAvailableForServiceType:SLServiceTypeTwitter])
    {
        SLComposeViewController *view = [SLComposeViewController composeViewControllerForServiceType:SLServiceTypeTwitter];
        [view setInitialText:@"Boom! Tweeting from an app I created while reading iOS in Action!"];
        [view addURL:[NSURL URLWithString:@"http://manning.com/lim2"]];
        [self presentViewController:view animated:YES completion:^{}];
    }
}

- (void)postToFacebook
{
    if([SLComposeViewController isAvailableForServiceType:SLServiceTypeFacebook])
    {
        SLComposeViewController *view = [SLComposeViewController composeViewControllerForServiceType:SLServiceTypeFacebook];
        [view setInitialText:@"Boom! Posting from an app I created while reading iOS in Action!"];
        [view addURL:[NSURL URLWithString:@"http://manning.com/lim2"]];
        [self presentViewController:view animated:YES completion:^{}];
    }
}

- (void)retrieveTwitterStream
{
    NSURL *url = [NSURL URLWithString:@"https://api.twitter.com/1.1/statuses/user_timeline.json"];
    NSDictionary *params = @{@"screen_name" : self.account.username };
    
    SLRequest *request = [SLRequest requestForServiceType:SLServiceTypeTwitter requestMethod:SLRequestMethodGET URL:url parameters:params];

    [request setAccount:self.account];
    [request performRequestWithHandler:^(NSData *responseData, NSHTTPURLResponse *response, NSError *error)
     {
         if (response.statusCode == 200)
         {
             NSError *parsingError = nil;
             self.updates = [NSJSONSerialization JSONObjectWithData:responseData options:0 error:&parsingError];
             
             dispatch_sync(dispatch_get_main_queue(),^{
                 [self.tableView reloadData];
             });
         }
     }];
}

- (void)retrieveFacebookStream
{
    NSDictionary *options = @{ ACFacebookAppIdKey: @"ADD YOUR KEY HERE",
                               ACFacebookPermissionsKey: @[@"read_stream"] };
    
    
    ACAccountStore *accountStore = [[ACAccountStore alloc] init];
    ACAccountType *accountType = [accountStore accountTypeWithAccountTypeIdentifier:ACAccountTypeIdentifierFacebook];
    
    [accountStore requestAccessToAccountsWithType:accountType options:options completion:^(BOOL granted, NSError *error)
     {
         if(granted)
         {
             for (ACAccount *account in [accountStore accountsWithAccountType:accountType])
             {
                 if ([account.username isEqual:self.account.username])
                     self.account = account;
             }
             
             NSURL *url = [NSURL URLWithString:@"https://graph.facebook.com/me/feed"];
             SLRequest *request = [SLRequest requestForServiceType:SLServiceTypeFacebook
                                                     requestMethod:SLRequestMethodGET
                                                               URL:url
                                                        parameters:nil];
             
             [request setAccount:self.account];
             
             [request performRequestWithHandler:^(NSData *responseData, NSHTTPURLResponse *response, NSError *error)
             {
                 if (response.statusCode == 200)
                 {
                     NSError *parsingError = nil;
                     self.updates = [[NSJSONSerialization JSONObjectWithData:responseData options:0 error:&parsingError] objectForKey:@"data"];

                     dispatch_sync(dispatch_get_main_queue(),^{
                         [self.tableView reloadData];
                     });
                 }
             }];
         }
     }];

    
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.updates count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"updateCell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    if (!cell)
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
    
    NSDictionary *update = self.updates[indexPath.row];
    
    if ([self.account.accountType.identifier isEqualToString:ACAccountTypeIdentifierTwitter])
    {
        cell.textLabel.text = [update objectForKey:@"text"];
        cell.detailTextLabel.text = [update valueForKeyPath:@"user.name"];
    }
    else
    {
        cell.textLabel.text = [update objectForKey:@"story"];
        cell.detailTextLabel.text = [update valueForKeyPath:@"from.name"];
    }

    return cell;
}


@end
